@@ -4,8 +4,8 @@ from takeme.RsaUtil import RsaUtil
 
 class TakemeClient:
 
-    def __init__(self, corporate_code, secret_key):
-        self.request_takeme = TakemeRequestor(corporate_code, secret_key)
+    def __init__(self, corporate_code, secret_key, is_production=False):
+        self.request_takeme = TakemeRequestor(corporate_code, secret_key, is_production)
 
     def non_auth_call(self, body, endpoint):
         response = self.request_takeme.call_api_without_bearer(endpoint, body)
